summaryrefslogtreecommitdiffstats
path: root/hl
diff options
context:
space:
mode:
authorElena Pourmal <epourmal@hdfgroup.org>2009-08-03 20:10:41 (GMT)
committerElena Pourmal <epourmal@hdfgroup.org>2009-08-03 20:10:41 (GMT)
commit98682148dd539ced810ba7d168bf38233d0ce32a (patch)
treec3b9acb305a844fcdb0f257c161e381e0992a2a1 /hl
parentcb2b63cd9a25795fc8c9dadb55e93313001318a2 (diff)
downloadhdf5-98682148dd539ced810ba7d168bf38233d0ce32a.zip
hdf5-98682148dd539ced810ba7d168bf38233d0ce32a.tar.gz
hdf5-98682148dd539ced810ba7d168bf38233d0ce32a.tar.bz2
[svn-r17296] Maintenance: Changed function name from
H5LRcreate_regref_to_all to H5LRcreate_ref_to_all as required by new spec. This change brings source in sync with the HL_NPOESS repository. Tested: jam (trivial change)
Diffstat (limited to 'hl')
-rw-r--r--hl/src/H5LR.c14
-rw-r--r--hl/src/H5LRpublic.h2
2 files changed, 8 insertions, 8 deletions
diff --git a/hl/src/H5LRpublic.h b/hl/src/H5LRpublic.h
index bb0e94b..6084eb2 100644
--- a/hl/src/H5LRpublic.h
+++ b/hl/src/H5LRpublic.h
@@ -63,7 +63,7 @@ H5_HLDLL herr_t H5LRcopy_region(hid_t obj_id,
const char *path,
const hsize_t *block_coord);
-H5_HLDLL herr_t H5LRcreate_regref_to_all(hid_t loc_id, const char *group_path,
+H5_HLDLL herr_t H5LRcreate_ref_to_all(hid_t loc_id, const char *group_path,
const char *ds_path, H5_index_t index_type, H5_iter_order_t order, H5R_type_t ref_type);
/*-------------------------------------------------------------------------
diff --git a/hl/src/H5LR.c b/hl/src/H5LR.c
index 7fb39ad..1c44020 100644
--- a/hl/src/H5LR.c
+++ b/hl/src/H5LR.c
@@ -79,11 +79,11 @@ hbool_t H5_H5LR_init_g = FALSE;
/* Local Variables */
/*******************/
/* THE FOLLOWING ARE USED BY HL API: H5LRcreate_regref_to_all */
/* starting index counter for placing region references into 1D array, used by H5LRcreate_regref_to_all */
static size_t _regref_to_all_start;
-/* size of the 1D array needed to hold all the region references created by H5LRcreate_regref_to_all */
+/* size of the 1D array needed to hold all the region references created by H5LRcreate_ref_to_all */
static hsize_t _regref_to_all_size;
/* type of data to create region references for */
static H5R_type_t _regref_type;
@@ -97,7 +97,7 @@ static H5R_type_t _regref_type;
/************************************************************
- Operator function used by HL API H5LRcreate_regref_to_all:
+ Operator function used by HL API H5LRcreate_ref_to_all:
(1) Finds the size (_regref_to_all_size) of the array needed to hold the
region references by finding: the number of datasets
(for _regref_type == H5R_DATASET_REGION) or number of objects
@@ -179,7 +179,7 @@ op_func(hid_t loc_id, const char *name, const H5O_info_t *info, void *operator_d
/************************************************************
Operator function for H5Lvisit_by_name, used by
- the HL API H5LRcreate_regref_to_all. This function simply
+ the HL API H5LRcreate_ref_to_all. This function simply
retrieves the info for the object the current link points
to, and calls the operator function, op_func.
@@ -1387,7 +1387,7 @@ END_FUNC(PUB)
/*-------------------------------------------------------------------------
- * Function: H5LRcreate_regref_to_all
+ * Function: H5LRcreate_ref_to_all
*
* Purpose: Create a dataset with the region references to all datasets or
* objects recursively located under a specified group in a file.
@@ -1402,7 +1402,7 @@ END_FUNC(PUB)
*/
BEGIN_FUNC(PUB, ERR,
herr_t, SUCCEED, FAIL,
-H5LRcreate_regref_to_all(hid_t loc_id, const char *group_path,
+H5LRcreate_ref_to_all(hid_t loc_id, const char *group_path,
const char *ds_path, H5_index_t index_type, H5_iter_order_t order, H5R_type_t ref_type))
herr_t status; /* API return status */
@@ -79,11 +79,11 @@ hbool_t H5_H5LR_init_g = FALSE;
/* Local Variables */
/*******************/
-/* THE FOLLOWING ARE USED BY HL API: H5LRcreate_regref_to_all */
+/* THE FOLLOWING ARE USED BY HL API: H5LRcreate_ref_to_all */
-/* starting index counter for placing region references into 1D array, used by H5LRcreate_regref_to_all */
+/* starting index counter for placing region references into 1D array, used by H5LRcreate_ref_to_all */
static size_t _regref_to_all_start;